/****************************************************************************
** Meta object code from reading C++ file 'playlist.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/juk-17.12.3/playlist.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'playlist.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Playlist_t {
    QByteArrayData data[60];
    char stringdata0[826];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Playlist_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Playlist_t qt_meta_stringdata_Playlist = {
    {
QT_MOC_LITERAL(0, 0, 8), // "Playlist"
QT_MOC_LITERAL(1, 9, 17), // "signalNameChanged"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 4), // "name"
QT_MOC_LITERAL(4, 33, 19), // "signalAboutToRemove"
QT_MOC_LITERAL(5, 53, 13), // "PlaylistItem*"
QT_MOC_LITERAL(6, 67, 4), // "item"
QT_MOC_LITERAL(7, 72, 20), // "signalEnableDirWatch"
QT_MOC_LITERAL(8, 93, 6), // "enable"
QT_MOC_LITERAL(9, 100, 26), // "signalPlaylistItemsDropped"
QT_MOC_LITERAL(10, 127, 9), // "Playlist*"
QT_MOC_LITERAL(11, 137, 1), // "p"
QT_MOC_LITERAL(12, 139, 23), // "slotRemoveSelectedItems"
QT_MOC_LITERAL(13, 163, 3), // "cut"
QT_MOC_LITERAL(14, 167, 4), // "copy"
QT_MOC_LITERAL(15, 172, 5), // "paste"
QT_MOC_LITERAL(16, 178, 5), // "clear"
QT_MOC_LITERAL(17, 184, 9), // "selectAll"
QT_MOC_LITERAL(18, 194, 11), // "slotRefresh"
QT_MOC_LITERAL(19, 206, 16), // "slotGuessTagInfo"
QT_MOC_LITERAL(20, 223, 16), // "TagGuesser::Type"
QT_MOC_LITERAL(21, 240, 4), // "type"
QT_MOC_LITERAL(22, 245, 14), // "slotRenameFile"
QT_MOC_LITERAL(23, 260, 12), // "slotAddCover"
QT_MOC_LITERAL(24, 273, 9), // "fromLocal"
QT_MOC_LITERAL(25, 283, 13), // "slotViewCover"
QT_MOC_LITERAL(26, 297, 15), // "slotRemoveCover"
QT_MOC_LITERAL(27, 313, 20), // "slotShowCoverManager"
QT_MOC_LITERAL(28, 334, 10), // "slotReload"
QT_MOC_LITERAL(29, 345, 15), // "slotWeightDirty"
QT_MOC_LITERAL(30, 361, 6), // "column"
QT_MOC_LITERAL(31, 368, 15), // "slotShowPlaying"
QT_MOC_LITERAL(32, 384, 27), // "slotColumnResizeModeChanged"
QT_MOC_LITERAL(33, 412, 20), // "playlistItemsChanged"
QT_MOC_LITERAL(34, 433, 20), // "slotPopulateBackMenu"
QT_MOC_LITERAL(35, 454, 20), // "slotPlayFromBackMenu"
QT_MOC_LITERAL(36, 475, 8), // "QAction*"
QT_MOC_LITERAL(37, 484, 14), // "slotInitialize"
QT_MOC_LITERAL(38, 499, 22), // "slotUpdateColumnWidths"
QT_MOC_LITERAL(39, 522, 17), // "slotAddToUpcoming"
QT_MOC_LITERAL(40, 540, 15), // "slotShowRMBMenu"
QT_MOC_LITERAL(41, 556, 5), // "point"
QT_MOC_LITERAL(42, 562, 18), // "slotInlineEditDone"
QT_MOC_LITERAL(43, 581, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(44, 598, 13), // "slotRenameTag"
QT_MOC_LITERAL(45, 612, 16), // "slotCoverChanged"
QT_MOC_LITERAL(46, 629, 7), // "coverId"
QT_MOC_LITERAL(47, 637, 22), // "slotColumnOrderChanged"
QT_MOC_LITERAL(48, 660, 4), // "from"
QT_MOC_LITERAL(49, 665, 2), // "to"
QT_MOC_LITERAL(50, 668, 23), // "slotToggleColumnVisible"
QT_MOC_LITERAL(51, 692, 6), // "action"
QT_MOC_LITERAL(52, 699, 15), // "slotCreateGroup"
QT_MOC_LITERAL(53, 715, 13), // "columnResized"
QT_MOC_LITERAL(54, 729, 7), // "oldSize"
QT_MOC_LITERAL(55, 737, 7), // "newSize"
QT_MOC_LITERAL(56, 745, 31), // "slotInlineCompletionModeChanged"
QT_MOC_LITERAL(57, 777, 27), // "KCompletion::CompletionMode"
QT_MOC_LITERAL(58, 805, 4), // "mode"
QT_MOC_LITERAL(59, 810, 15) // "slotPlayCurrent"

    },
    "Playlist\0signalNameChanged\0\0name\0"
    "signalAboutToRemove\0PlaylistItem*\0"
    "item\0signalEnableDirWatch\0enable\0"
    "signalPlaylistItemsDropped\0Playlist*\0"
    "p\0slotRemoveSelectedItems\0cut\0copy\0"
    "paste\0clear\0selectAll\0slotRefresh\0"
    "slotGuessTagInfo\0TagGuesser::Type\0"
    "type\0slotRenameFile\0slotAddCover\0"
    "fromLocal\0slotViewCover\0slotRemoveCover\0"
    "slotShowCoverManager\0slotReload\0"
    "slotWeightDirty\0column\0slotShowPlaying\0"
    "slotColumnResizeModeChanged\0"
    "playlistItemsChanged\0slotPopulateBackMenu\0"
    "slotPlayFromBackMenu\0QAction*\0"
    "slotInitialize\0slotUpdateColumnWidths\0"
    "slotAddToUpcoming\0slotShowRMBMenu\0"
    "point\0slotInlineEditDone\0QTreeWidgetItem*\0"
    "slotRenameTag\0slotCoverChanged\0coverId\0"
    "slotColumnOrderChanged\0from\0to\0"
    "slotToggleColumnVisible\0action\0"
    "slotCreateGroup\0columnResized\0oldSize\0"
    "newSize\0slotInlineCompletionModeChanged\0"
    "KCompletion::CompletionMode\0mode\0"
    "slotPlayCurrent"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Playlist[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      38,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  204,    2, 0x06 /* Public */,
       4,    1,  207,    2, 0x06 /* Public */,
       7,    1,  210,    2, 0x06 /* Public */,
       9,    1,  213,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      12,    0,  216,    2, 0x0a /* Public */,
      13,    0,  217,    2, 0x0a /* Public */,
      14,    0,  218,    2, 0x0a /* Public */,
      15,    0,  219,    2, 0x0a /* Public */,
      16,    0,  220,    2, 0x0a /* Public */,
      17,    0,  221,    2, 0x0a /* Public */,
      18,    0,  222,    2, 0x0a /* Public */,
      19,    1,  223,    2, 0x0a /* Public */,
      22,    0,  226,    2, 0x0a /* Public */,
      23,    1,  227,    2, 0x0a /* Public */,
      25,    0,  230,    2, 0x0a /* Public */,
      26,    0,  231,    2, 0x0a /* Public */,
      27,    0,  232,    2, 0x0a /* Public */,
      28,    0,  233,    2, 0x0a /* Public */,
      29,    1,  234,    2, 0x0a /* Public */,
      29,    0,  237,    2, 0x2a /* Public | MethodCloned */,
      31,    0,  238,    2, 0x0a /* Public */,
      32,    0,  239,    2, 0x0a /* Public */,
      33,    0,  240,    2, 0x0a /* Public */,
      34,    0,  241,    2, 0x09 /* Protected */,
      35,    1,  242,    2, 0x09 /* Protected */,
      37,    0,  245,    2, 0x08 /* Private */,
      38,    0,  246,    2, 0x08 /* Private */,
      39,    0,  247,    2, 0x08 /* Private */,
      40,    1,  248,    2, 0x08 /* Private */,
      42,    3,  251,    2, 0x08 /* Private */,
      44,    0,  258,    2, 0x08 /* Private */,
      45,    1,  259,    2, 0x08 /* Private */,
      47,    3,  262,    2, 0x08 /* Private */,
      50,    1,  269,    2, 0x08 /* Private */,
      52,    0,  272,    2, 0x08 /* Private */,
      53,    3,  273,    2, 0x08 /* Private */,
      56,    1,  280,    2, 0x08 /* Private */,
      59,    0,  283,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, QMetaType::Bool,    8,
    QMetaType::Void, 0x80000000 | 10,   11,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 20,   21,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   24,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   30,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 36,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPoint,   41,
    QMetaType::Void, 0x80000000 | 43, QMetaType::QString, QMetaType::Int,    2,    2,   30,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   46,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int,    2,   48,   49,
    QMetaType::Void, 0x80000000 | 36,   51,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int,   30,   54,   55,
    QMetaType::Void, 0x80000000 | 57,   58,
    QMetaType::Void,

       0        // eod
};

void Playlist::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Playlist *_t = static_cast<Playlist *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->signalNameChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->signalAboutToRemove((*reinterpret_cast< PlaylistItem*(*)>(_a[1]))); break;
        case 2: _t->signalEnableDirWatch((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->signalPlaylistItemsDropped((*reinterpret_cast< Playlist*(*)>(_a[1]))); break;
        case 4: _t->slotRemoveSelectedItems(); break;
        case 5: _t->cut(); break;
        case 6: _t->copy(); break;
        case 7: _t->paste(); break;
        case 8: _t->clear(); break;
        case 9: _t->selectAll(); break;
        case 10: _t->slotRefresh(); break;
        case 11: _t->slotGuessTagInfo((*reinterpret_cast< TagGuesser::Type(*)>(_a[1]))); break;
        case 12: _t->slotRenameFile(); break;
        case 13: _t->slotAddCover((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 14: _t->slotViewCover(); break;
        case 15: _t->slotRemoveCover(); break;
        case 16: _t->slotShowCoverManager(); break;
        case 17: _t->slotReload(); break;
        case 18: _t->slotWeightDirty((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 19: _t->slotWeightDirty(); break;
        case 20: _t->slotShowPlaying(); break;
        case 21: _t->slotColumnResizeModeChanged(); break;
        case 22: _t->playlistItemsChanged(); break;
        case 23: _t->slotPopulateBackMenu(); break;
        case 24: _t->slotPlayFromBackMenu((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 25: _t->slotInitialize(); break;
        case 26: _t->slotUpdateColumnWidths(); break;
        case 27: _t->slotAddToUpcoming(); break;
        case 28: _t->slotShowRMBMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 29: _t->slotInlineEditDone((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 30: _t->slotRenameTag(); break;
        case 31: _t->slotCoverChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 32: _t->slotColumnOrderChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 33: _t->slotToggleColumnVisible((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 34: _t->slotCreateGroup(); break;
        case 35: _t->columnResized((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 36: _t->slotInlineCompletionModeChanged((*reinterpret_cast< KCompletion::CompletionMode(*)>(_a[1]))); break;
        case 37: _t->slotPlayCurrent(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Playlist* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Playlist::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Playlist::signalNameChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Playlist::*_t)(PlaylistItem * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Playlist::signalAboutToRemove)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Playlist::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Playlist::signalEnableDirWatch)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Playlist::*_t)(Playlist * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Playlist::signalPlaylistItemsDropped)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject Playlist::staticMetaObject = {
    { &QTreeWidget::staticMetaObject, qt_meta_stringdata_Playlist.data,
      qt_meta_data_Playlist,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Playlist::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Playlist::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Playlist.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "PlaylistInterface"))
        return static_cast< PlaylistInterface*>(this);
    return QTreeWidget::qt_metacast(_clname);
}

int Playlist::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    return _id;
}

// SIGNAL 0
void Playlist::signalNameChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Playlist::signalAboutToRemove(PlaylistItem * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Playlist::signalEnableDirWatch(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Playlist::signalPlaylistItemsDropped(Playlist * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
