/****************************************************************************
** Meta object code from reading C++ file 'exampleoptions.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/juk-17.12.3/exampleoptions.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'exampleoptions.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ExampleOptions_t {
    QByteArrayData data[7];
    char stringdata0[102];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ExampleOptions_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ExampleOptions_t qt_meta_stringdata_ExampleOptions = {
    {
QT_MOC_LITERAL(0, 0, 14), // "ExampleOptions"
QT_MOC_LITERAL(1, 15, 11), // "dataChanged"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 11), // "fileChanged"
QT_MOC_LITERAL(4, 40, 23), // "exampleSelectionChanged"
QT_MOC_LITERAL(5, 64, 18), // "exampleDataChanged"
QT_MOC_LITERAL(6, 83, 18) // "exampleFileChanged"

    },
    "ExampleOptions\0dataChanged\0\0fileChanged\0"
    "exampleSelectionChanged\0exampleDataChanged\0"
    "exampleFileChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ExampleOptions[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   39,    2, 0x06 /* Public */,
       3,    0,   40,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,   41,    2, 0x09 /* Protected */,
       5,    0,   42,    2, 0x09 /* Protected */,
       6,    0,   43,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void ExampleOptions::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ExampleOptions *_t = static_cast<ExampleOptions *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->dataChanged(); break;
        case 1: _t->fileChanged(); break;
        case 2: _t->exampleSelectionChanged(); break;
        case 3: _t->exampleDataChanged(); break;
        case 4: _t->exampleFileChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ExampleOptions::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ExampleOptions::dataChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ExampleOptions::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ExampleOptions::fileChanged)) {
                *result = 1;
                return;
            }
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject ExampleOptions::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_ExampleOptions.data,
      qt_meta_data_ExampleOptions,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ExampleOptions::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ExampleOptions::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ExampleOptions.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::ExampleOptionsBase"))
        return static_cast< Ui::ExampleOptionsBase*>(this);
    return QWidget::qt_metacast(_clname);
}

int ExampleOptions::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void ExampleOptions::dataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ExampleOptions::fileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
struct qt_meta_stringdata_ExampleOptionsDialog_t {
    QByteArrayData data[8];
    char stringdata0[99];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ExampleOptionsDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ExampleOptionsDialog_t qt_meta_stringdata_ExampleOptionsDialog = {
    {
QT_MOC_LITERAL(0, 0, 20), // "ExampleOptionsDialog"
QT_MOC_LITERAL(1, 21, 11), // "fileChanged"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 11), // "dataChanged"
QT_MOC_LITERAL(4, 46, 12), // "signalHidden"
QT_MOC_LITERAL(5, 59, 11), // "signalShown"
QT_MOC_LITERAL(6, 71, 16), // "fileModeSelected"
QT_MOC_LITERAL(7, 88, 10) // "urlChanged"

    },
    "ExampleOptionsDialog\0fileChanged\0\0"
    "dataChanged\0signalHidden\0signalShown\0"
    "fileModeSelected\0urlChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ExampleOptionsDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x06 /* Public */,
       3,    0,   47,    2, 0x06 /* Public */,
       4,    0,   48,    2, 0x06 /* Public */,
       5,    0,   49,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    0,   50,    2, 0x09 /* Protected */,
       7,    1,   51,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUrl,    2,

       0        // eod
};

void ExampleOptionsDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ExampleOptionsDialog *_t = static_cast<ExampleOptionsDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->fileChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->dataChanged(); break;
        case 2: _t->signalHidden(); break;
        case 3: _t->signalShown(); break;
        case 4: _t->fileModeSelected(); break;
        case 5: _t->urlChanged((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ExampleOptionsDialog::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ExampleOptionsDialog::fileChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ExampleOptionsDialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ExampleOptionsDialog::dataChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (ExampleOptionsDialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ExampleOptionsDialog::signalHidden)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (ExampleOptionsDialog::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ExampleOptionsDialog::signalShown)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject ExampleOptionsDialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_ExampleOptionsDialog.data,
      qt_meta_data_ExampleOptionsDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *ExampleOptionsDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ExampleOptionsDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ExampleOptionsDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int ExampleOptionsDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void ExampleOptionsDialog::fileChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void ExampleOptionsDialog::dataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ExampleOptionsDialog::signalHidden()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ExampleOptionsDialog::signalShown()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
