/****************************************************************************
** Meta object code from reading C++ file 'collectionlist.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/juk-17.12.3/collectionlist.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'collectionlist.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CollectionList_t {
    QByteArrayData data[22];
    char stringdata0[357];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CollectionList_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CollectionList_t qt_meta_stringdata_CollectionList = {
    {
QT_MOC_LITERAL(0, 0, 14), // "CollectionList"
QT_MOC_LITERAL(1, 15, 23), // "signalCollectionChanged"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 27), // "signalVisibleColumnsChanged"
QT_MOC_LITERAL(4, 68, 12), // "signalNewTag"
QT_MOC_LITERAL(5, 81, 16), // "signalRemovedTag"
QT_MOC_LITERAL(6, 98, 17), // "cachedItemsLoaded"
QT_MOC_LITERAL(7, 116, 5), // "paste"
QT_MOC_LITERAL(8, 122, 5), // "clear"
QT_MOC_LITERAL(9, 128, 14), // "slotCheckCache"
QT_MOC_LITERAL(10, 143, 14), // "slotRemoveItem"
QT_MOC_LITERAL(11, 158, 4), // "file"
QT_MOC_LITERAL(12, 163, 15), // "slotRefreshItem"
QT_MOC_LITERAL(13, 179, 12), // "slotNewItems"
QT_MOC_LITERAL(14, 192, 13), // "KFileItemList"
QT_MOC_LITERAL(15, 206, 5), // "items"
QT_MOC_LITERAL(16, 212, 16), // "slotRefreshItems"
QT_MOC_LITERAL(17, 229, 34), // "QList<QPair<KFileItem,KFileIt..."
QT_MOC_LITERAL(18, 264, 15), // "slotDeleteItems"
QT_MOC_LITERAL(19, 280, 23), // "startLoadingCachedItems"
QT_MOC_LITERAL(20, 304, 24), // "loadNextBatchCachedItems"
QT_MOC_LITERAL(21, 329, 27) // "completedLoadingCachedItems"

    },
    "CollectionList\0signalCollectionChanged\0"
    "\0signalVisibleColumnsChanged\0signalNewTag\0"
    "signalRemovedTag\0cachedItemsLoaded\0"
    "paste\0clear\0slotCheckCache\0slotRemoveItem\0"
    "file\0slotRefreshItem\0slotNewItems\0"
    "KFileItemList\0items\0slotRefreshItems\0"
    "QList<QPair<KFileItem,KFileItem> >\0"
    "slotDeleteItems\0startLoadingCachedItems\0"
    "loadNextBatchCachedItems\0"
    "completedLoadingCachedItems"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CollectionList[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      16,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   94,    2, 0x06 /* Public */,
       3,    0,   95,    2, 0x06 /* Public */,
       4,    2,   96,    2, 0x06 /* Public */,
       5,    2,  101,    2, 0x06 /* Public */,
       6,    0,  106,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    0,  107,    2, 0x0a /* Public */,
       8,    0,  108,    2, 0x0a /* Public */,
       9,    0,  109,    2, 0x0a /* Public */,
      10,    1,  110,    2, 0x0a /* Public */,
      12,    1,  113,    2, 0x0a /* Public */,
      13,    1,  116,    2, 0x0a /* Public */,
      16,    1,  119,    2, 0x0a /* Public */,
      18,    1,  122,    2, 0x0a /* Public */,
      19,    0,  125,    2, 0x0a /* Public */,
      20,    0,  126,    2, 0x0a /* Public */,
      21,    0,  127,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::UInt,    2,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::UInt,    2,    2,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void, 0x80000000 | 17,   15,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void CollectionList::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        CollectionList *_t = static_cast<CollectionList *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->signalCollectionChanged(); break;
        case 1: _t->signalVisibleColumnsChanged(); break;
        case 2: _t->signalNewTag((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 3: _t->signalRemovedTag((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 4: _t->cachedItemsLoaded(); break;
        case 5: _t->paste(); break;
        case 6: _t->clear(); break;
        case 7: _t->slotCheckCache(); break;
        case 8: _t->slotRemoveItem((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->slotRefreshItem((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->slotNewItems((*reinterpret_cast< const KFileItemList(*)>(_a[1]))); break;
        case 11: _t->slotRefreshItems((*reinterpret_cast< const QList<QPair<KFileItem,KFileItem> >(*)>(_a[1]))); break;
        case 12: _t->slotDeleteItems((*reinterpret_cast< const KFileItemList(*)>(_a[1]))); break;
        case 13: _t->startLoadingCachedItems(); break;
        case 14: _t->loadNextBatchCachedItems(); break;
        case 15: _t->completedLoadingCachedItems(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (CollectionList::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CollectionList::signalCollectionChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (CollectionList::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CollectionList::signalVisibleColumnsChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (CollectionList::*_t)(const QString & , unsigned  );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CollectionList::signalNewTag)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (CollectionList::*_t)(const QString & , unsigned  );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CollectionList::signalRemovedTag)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (CollectionList::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CollectionList::cachedItemsLoaded)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject CollectionList::staticMetaObject = {
    { &Playlist::staticMetaObject, qt_meta_stringdata_CollectionList.data,
      qt_meta_data_CollectionList,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *CollectionList::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CollectionList::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CollectionList.stringdata0))
        return static_cast<void*>(this);
    return Playlist::qt_metacast(_clname);
}

int CollectionList::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Playlist::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void CollectionList::signalCollectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void CollectionList::signalVisibleColumnsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void CollectionList::signalNewTag(const QString & _t1, unsigned  _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void CollectionList::signalRemovedTag(const QString & _t1, unsigned  _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void CollectionList::cachedItemsLoaded()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
