/****************************************************************************
** Meta object code from reading C++ file 'juk.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/juk-17.12.3/juk.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'juk.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_JuK_t {
    QByteArrayData data[17];
    char stringdata0[266];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_JuK_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_JuK_t qt_meta_stringdata_JuK = {
    {
QT_MOC_LITERAL(0, 0, 3), // "JuK"
QT_MOC_LITERAL(1, 4, 19), // "slotSetupSystemTray"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 12), // "slotShowHide"
QT_MOC_LITERAL(4, 38, 15), // "slotAboutToQuit"
QT_MOC_LITERAL(5, 54, 8), // "slotQuit"
QT_MOC_LITERAL(6, 63, 20), // "slotToggleSystemTray"
QT_MOC_LITERAL(7, 84, 7), // "enabled"
QT_MOC_LITERAL(8, 92, 12), // "slotEditKeys"
QT_MOC_LITERAL(9, 105, 23), // "slotConfigureTagGuesser"
QT_MOC_LITERAL(10, 129, 24), // "slotConfigureFileRenamer"
QT_MOC_LITERAL(11, 154, 23), // "slotConfigureScrobbling"
QT_MOC_LITERAL(12, 178, 8), // "slotUndo"
QT_MOC_LITERAL(13, 187, 24), // "slotCheckAlbumNextAction"
QT_MOC_LITERAL(14, 212, 18), // "albumRandomEnabled"
QT_MOC_LITERAL(15, 231, 15), // "slotProcessArgs"
QT_MOC_LITERAL(16, 247, 18) // "slotClearOldCovers"

    },
    "JuK\0slotSetupSystemTray\0\0slotShowHide\0"
    "slotAboutToQuit\0slotQuit\0slotToggleSystemTray\0"
    "enabled\0slotEditKeys\0slotConfigureTagGuesser\0"
    "slotConfigureFileRenamer\0"
    "slotConfigureScrobbling\0slotUndo\0"
    "slotCheckAlbumNextAction\0albumRandomEnabled\0"
    "slotProcessArgs\0slotClearOldCovers"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_JuK[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   79,    2, 0x08 /* Private */,
       3,    0,   80,    2, 0x08 /* Private */,
       4,    0,   81,    2, 0x08 /* Private */,
       5,    0,   82,    2, 0x08 /* Private */,
       6,    1,   83,    2, 0x08 /* Private */,
       8,    0,   86,    2, 0x08 /* Private */,
       9,    0,   87,    2, 0x08 /* Private */,
      10,    0,   88,    2, 0x08 /* Private */,
      11,    0,   89,    2, 0x08 /* Private */,
      12,    0,   90,    2, 0x08 /* Private */,
      13,    1,   91,    2, 0x08 /* Private */,
      15,    0,   94,    2, 0x08 /* Private */,
      16,    0,   95,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void JuK::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        JuK *_t = static_cast<JuK *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotSetupSystemTray(); break;
        case 1: _t->slotShowHide(); break;
        case 2: _t->slotAboutToQuit(); break;
        case 3: _t->slotQuit(); break;
        case 4: _t->slotToggleSystemTray((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->slotEditKeys(); break;
        case 6: _t->slotConfigureTagGuesser(); break;
        case 7: _t->slotConfigureFileRenamer(); break;
        case 8: _t->slotConfigureScrobbling(); break;
        case 9: _t->slotUndo(); break;
        case 10: _t->slotCheckAlbumNextAction((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->slotProcessArgs(); break;
        case 12: _t->slotClearOldCovers(); break;
        default: ;
        }
    }
}

const QMetaObject JuK::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_JuK.data,
      qt_meta_data_JuK,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *JuK::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *JuK::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_JuK.stringdata0))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int JuK::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
