/****************************************************************************
** Meta object code from reading C++ file 'systemtray.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/juk-17.12.3/systemtray.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'systemtray.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_PassiveInfo_t {
    QByteArrayData data[10];
    char stringdata0[95];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PassiveInfo_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PassiveInfo_t qt_meta_stringdata_PassiveInfo = {
    {
QT_MOC_LITERAL(0, 0, 11), // "PassiveInfo"
QT_MOC_LITERAL(1, 12, 12), // "mouseEntered"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 11), // "timeExpired"
QT_MOC_LITERAL(4, 38, 12), // "previousSong"
QT_MOC_LITERAL(5, 51, 8), // "nextSong"
QT_MOC_LITERAL(6, 60, 10), // "startTimer"
QT_MOC_LITERAL(7, 71, 5), // "delay"
QT_MOC_LITERAL(8, 77, 4), // "show"
QT_MOC_LITERAL(9, 82, 12) // "timerExpired"

    },
    "PassiveInfo\0mouseEntered\0\0timeExpired\0"
    "previousSong\0nextSong\0startTimer\0delay\0"
    "show\0timerExpired"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PassiveInfo[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x06 /* Public */,
       3,    0,   50,    2, 0x06 /* Public */,
       4,    0,   51,    2, 0x06 /* Public */,
       5,    0,   52,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    1,   53,    2, 0x0a /* Public */,
       8,    0,   56,    2, 0x0a /* Public */,
       9,    0,   57,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void PassiveInfo::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        PassiveInfo *_t = static_cast<PassiveInfo *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->mouseEntered(); break;
        case 1: _t->timeExpired(); break;
        case 2: _t->previousSong(); break;
        case 3: _t->nextSong(); break;
        case 4: _t->startTimer((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->show(); break;
        case 6: _t->timerExpired(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (PassiveInfo::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PassiveInfo::mouseEntered)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (PassiveInfo::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PassiveInfo::timeExpired)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (PassiveInfo::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PassiveInfo::previousSong)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (PassiveInfo::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PassiveInfo::nextSong)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject PassiveInfo::staticMetaObject = {
    { &QFrame::staticMetaObject, qt_meta_stringdata_PassiveInfo.data,
      qt_meta_data_PassiveInfo,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *PassiveInfo::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PassiveInfo::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_PassiveInfo.stringdata0))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int PassiveInfo::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void PassiveInfo::mouseEntered()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PassiveInfo::timeExpired()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PassiveInfo::previousSong()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PassiveInfo::nextSong()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
struct qt_meta_stringdata_SystemTray_t {
    QByteArrayData data[17];
    char stringdata0[197];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SystemTray_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SystemTray_t qt_meta_stringdata_SystemTray = {
    {
QT_MOC_LITERAL(0, 0, 10), // "SystemTray"
QT_MOC_LITERAL(1, 11, 8), // "fadeDone"
QT_MOC_LITERAL(2, 20, 0), // ""
QT_MOC_LITERAL(3, 21, 8), // "slotPlay"
QT_MOC_LITERAL(4, 30, 9), // "slotPause"
QT_MOC_LITERAL(5, 40, 8), // "slotStop"
QT_MOC_LITERAL(6, 49, 18), // "slotPopupDestroyed"
QT_MOC_LITERAL(7, 68, 12), // "slotNextStep"
QT_MOC_LITERAL(8, 81, 19), // "slotPopupLargeCover"
QT_MOC_LITERAL(9, 101, 11), // "slotForward"
QT_MOC_LITERAL(10, 113, 8), // "slotBack"
QT_MOC_LITERAL(11, 122, 11), // "slotFadeOut"
QT_MOC_LITERAL(12, 134, 16), // "slotMouseInPopup"
QT_MOC_LITERAL(13, 151, 11), // "scrollEvent"
QT_MOC_LITERAL(14, 163, 5), // "delta"
QT_MOC_LITERAL(15, 169, 15), // "Qt::Orientation"
QT_MOC_LITERAL(16, 185, 11) // "orientation"

    },
    "SystemTray\0fadeDone\0\0slotPlay\0slotPause\0"
    "slotStop\0slotPopupDestroyed\0slotNextStep\0"
    "slotPopupLargeCover\0slotForward\0"
    "slotBack\0slotFadeOut\0slotMouseInPopup\0"
    "scrollEvent\0delta\0Qt::Orientation\0"
    "orientation"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SystemTray[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   74,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   75,    2, 0x08 /* Private */,
       4,    0,   76,    2, 0x08 /* Private */,
       5,    0,   77,    2, 0x08 /* Private */,
       6,    0,   78,    2, 0x08 /* Private */,
       7,    0,   79,    2, 0x08 /* Private */,
       8,    0,   80,    2, 0x08 /* Private */,
       9,    0,   81,    2, 0x08 /* Private */,
      10,    0,   82,    2, 0x08 /* Private */,
      11,    0,   83,    2, 0x08 /* Private */,
      12,    0,   84,    2, 0x08 /* Private */,
      13,    2,   85,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 15,   14,   16,

       0        // eod
};

void SystemTray::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        SystemTray *_t = static_cast<SystemTray *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->fadeDone(); break;
        case 1: _t->slotPlay(); break;
        case 2: _t->slotPause(); break;
        case 3: _t->slotStop(); break;
        case 4: _t->slotPopupDestroyed(); break;
        case 5: _t->slotNextStep(); break;
        case 6: _t->slotPopupLargeCover(); break;
        case 7: _t->slotForward(); break;
        case 8: _t->slotBack(); break;
        case 9: _t->slotFadeOut(); break;
        case 10: _t->slotMouseInPopup(); break;
        case 11: _t->scrollEvent((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< Qt::Orientation(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (SystemTray::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SystemTray::fadeDone)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject SystemTray::staticMetaObject = {
    { &KStatusNotifierItem::staticMetaObject, qt_meta_stringdata_SystemTray.data,
      qt_meta_data_SystemTray,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *SystemTray::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SystemTray::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_SystemTray.stringdata0))
        return static_cast<void*>(this);
    return KStatusNotifierItem::qt_metacast(_clname);
}

int SystemTray::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KStatusNotifierItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void SystemTray::fadeDone()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
