/****************************************************************************
** Meta object code from reading C++ file 'filerenamer.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/juk-17.12.3/filerenamer.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filerenamer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_FileRenamerWidget_t {
    QByteArrayData data[17];
    char stringdata0[221];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_FileRenamerWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_FileRenamerWidget_t qt_meta_stringdata_FileRenamerWidget = {
    {
QT_MOC_LITERAL(0, 0, 17), // "FileRenamerWidget"
QT_MOC_LITERAL(1, 18, 8), // "accepted"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 8), // "rejected"
QT_MOC_LITERAL(4, 37, 18), // "exampleTextChanged"
QT_MOC_LITERAL(5, 56, 19), // "toggleExampleDialog"
QT_MOC_LITERAL(6, 76, 14), // "insertCategory"
QT_MOC_LITERAL(7, 91, 12), // "fileSelected"
QT_MOC_LITERAL(8, 104, 4), // "file"
QT_MOC_LITERAL(9, 109, 12), // "dataSelected"
QT_MOC_LITERAL(10, 122, 18), // "showCategoryOption"
QT_MOC_LITERAL(11, 141, 2), // "id"
QT_MOC_LITERAL(12, 144, 13), // "slotRemoveRow"
QT_MOC_LITERAL(13, 158, 10), // "moveItemUp"
QT_MOC_LITERAL(14, 169, 12), // "moveItemDown"
QT_MOC_LITERAL(15, 182, 18), // "exampleDialogShown"
QT_MOC_LITERAL(16, 201, 19) // "exampleDialogHidden"

    },
    "FileRenamerWidget\0accepted\0\0rejected\0"
    "exampleTextChanged\0toggleExampleDialog\0"
    "insertCategory\0fileSelected\0file\0"
    "dataSelected\0showCategoryOption\0id\0"
    "slotRemoveRow\0moveItemUp\0moveItemDown\0"
    "exampleDialogShown\0exampleDialogHidden"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_FileRenamerWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   79,    2, 0x06 /* Public */,
       3,    0,   80,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,   81,    2, 0x09 /* Protected */,
       5,    0,   82,    2, 0x09 /* Protected */,
       6,    0,   83,    2, 0x09 /* Protected */,
       7,    1,   84,    2, 0x08 /* Private */,
       9,    0,   87,    2, 0x08 /* Private */,
      10,    1,   88,    2, 0x08 /* Private */,
      12,    1,   91,    2, 0x08 /* Private */,
      13,    1,   94,    2, 0x08 /* Private */,
      14,    1,   97,    2, 0x08 /* Private */,
      15,    0,  100,    2, 0x08 /* Private */,
      16,    0,  101,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    8,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void FileRenamerWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        FileRenamerWidget *_t = static_cast<FileRenamerWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->accepted(); break;
        case 1: _t->rejected(); break;
        case 2: _t->exampleTextChanged(); break;
        case 3: _t->toggleExampleDialog(); break;
        case 4: _t->insertCategory(); break;
        case 5: _t->fileSelected((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->dataSelected(); break;
        case 7: _t->showCategoryOption((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->slotRemoveRow((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->moveItemUp((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->moveItemDown((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->exampleDialogShown(); break;
        case 12: _t->exampleDialogHidden(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (FileRenamerWidget::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FileRenamerWidget::accepted)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (FileRenamerWidget::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FileRenamerWidget::rejected)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject FileRenamerWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_FileRenamerWidget.data,
      qt_meta_data_FileRenamerWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *FileRenamerWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FileRenamerWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_FileRenamerWidget.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "CategoryReaderInterface"))
        return static_cast< CategoryReaderInterface*>(this);
    return QWidget::qt_metacast(_clname);
}

int FileRenamerWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void FileRenamerWidget::accepted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void FileRenamerWidget::rejected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
