/****************************************************************************
** Meta object code from reading C++ file 'playlistbox.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/juk-17.12.3/playlistbox.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'playlistbox.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_PlaylistBox_t {
    QByteArrayData data[31];
    char stringdata0[441];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PlaylistBox_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PlaylistBox_t qt_meta_stringdata_PlaylistBox = {
    {
QT_MOC_LITERAL(0, 0, 11), // "PlaylistBox"
QT_MOC_LITERAL(1, 12, 23), // "signalPlaylistDestroyed"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 9), // "Playlist*"
QT_MOC_LITERAL(4, 47, 15), // "startupComplete"
QT_MOC_LITERAL(5, 63, 17), // "startFilePlayback"
QT_MOC_LITERAL(6, 81, 10), // "FileHandle"
QT_MOC_LITERAL(7, 92, 4), // "file"
QT_MOC_LITERAL(8, 97, 5), // "paste"
QT_MOC_LITERAL(9, 103, 5), // "clear"
QT_MOC_LITERAL(10, 109, 19), // "slotFreezePlaylists"
QT_MOC_LITERAL(11, 129, 21), // "slotUnfreezePlaylists"
QT_MOC_LITERAL(12, 151, 23), // "slotPlaylistDataChanged"
QT_MOC_LITERAL(13, 175, 29), // "slotSetHistoryPlaylistEnabled"
QT_MOC_LITERAL(14, 205, 6), // "enable"
QT_MOC_LITERAL(15, 212, 19), // "slotPlaylistChanged"
QT_MOC_LITERAL(16, 232, 17), // "slotDoubleClicked"
QT_MOC_LITERAL(17, 250, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(18, 267, 19), // "slotShowContextMenu"
QT_MOC_LITERAL(19, 287, 5), // "point"
QT_MOC_LITERAL(20, 293, 15), // "slotSetViewMode"
QT_MOC_LITERAL(21, 309, 5), // "index"
QT_MOC_LITERAL(22, 315, 17), // "slotSavePlaylists"
QT_MOC_LITERAL(23, 333, 18), // "slotShowDropTarget"
QT_MOC_LITERAL(24, 352, 24), // "slotPlaylistItemsDropped"
QT_MOC_LITERAL(25, 377, 1), // "p"
QT_MOC_LITERAL(26, 379, 11), // "slotAddItem"
QT_MOC_LITERAL(27, 391, 3), // "tag"
QT_MOC_LITERAL(28, 395, 6), // "column"
QT_MOC_LITERAL(29, 402, 14), // "slotRemoveItem"
QT_MOC_LITERAL(30, 417, 23) // "slotLoadCachedPlaylists"

    },
    "PlaylistBox\0signalPlaylistDestroyed\0"
    "\0Playlist*\0startupComplete\0startFilePlayback\0"
    "FileHandle\0file\0paste\0clear\0"
    "slotFreezePlaylists\0slotUnfreezePlaylists\0"
    "slotPlaylistDataChanged\0"
    "slotSetHistoryPlaylistEnabled\0enable\0"
    "slotPlaylistChanged\0slotDoubleClicked\0"
    "QTreeWidgetItem*\0slotShowContextMenu\0"
    "point\0slotSetViewMode\0index\0"
    "slotSavePlaylists\0slotShowDropTarget\0"
    "slotPlaylistItemsDropped\0p\0slotAddItem\0"
    "tag\0column\0slotRemoveItem\0"
    "slotLoadCachedPlaylists"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PlaylistBox[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      19,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  109,    2, 0x06 /* Public */,
       4,    0,  112,    2, 0x06 /* Public */,
       5,    1,  113,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    0,  116,    2, 0x0a /* Public */,
       9,    0,  117,    2, 0x0a /* Public */,
      10,    0,  118,    2, 0x0a /* Public */,
      11,    0,  119,    2, 0x0a /* Public */,
      12,    0,  120,    2, 0x0a /* Public */,
      13,    1,  121,    2, 0x0a /* Public */,
      15,    0,  124,    2, 0x08 /* Private */,
      16,    1,  125,    2, 0x08 /* Private */,
      18,    1,  128,    2, 0x08 /* Private */,
      20,    1,  131,    2, 0x08 /* Private */,
      22,    0,  134,    2, 0x08 /* Private */,
      23,    0,  135,    2, 0x08 /* Private */,
      24,    1,  136,    2, 0x08 /* Private */,
      26,    2,  139,    2, 0x08 /* Private */,
      29,    2,  144,    2, 0x08 /* Private */,
      30,    0,  149,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 6,    7,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 17,    2,
    QMetaType::Void, QMetaType::QPoint,   19,
    QMetaType::Void, QMetaType::Int,   21,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,   25,
    QMetaType::Void, QMetaType::QString, QMetaType::UInt,   27,   28,
    QMetaType::Void, QMetaType::QString, QMetaType::UInt,   27,   28,
    QMetaType::Void,

       0        // eod
};

void PlaylistBox::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        PlaylistBox *_t = static_cast<PlaylistBox *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->signalPlaylistDestroyed((*reinterpret_cast< Playlist*(*)>(_a[1]))); break;
        case 1: _t->startupComplete(); break;
        case 2: _t->startFilePlayback((*reinterpret_cast< const FileHandle(*)>(_a[1]))); break;
        case 3: _t->paste(); break;
        case 4: _t->clear(); break;
        case 5: _t->slotFreezePlaylists(); break;
        case 6: _t->slotUnfreezePlaylists(); break;
        case 7: _t->slotPlaylistDataChanged(); break;
        case 8: _t->slotSetHistoryPlaylistEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->slotPlaylistChanged(); break;
        case 10: _t->slotDoubleClicked((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1]))); break;
        case 11: _t->slotShowContextMenu((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 12: _t->slotSetViewMode((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->slotSavePlaylists(); break;
        case 14: _t->slotShowDropTarget(); break;
        case 15: _t->slotPlaylistItemsDropped((*reinterpret_cast< Playlist*(*)>(_a[1]))); break;
        case 16: _t->slotAddItem((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 17: _t->slotRemoveItem((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 18: _t->slotLoadCachedPlaylists(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (PlaylistBox::*_t)(Playlist * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlaylistBox::signalPlaylistDestroyed)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (PlaylistBox::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlaylistBox::startupComplete)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (PlaylistBox::*_t)(const FileHandle & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlaylistBox::startFilePlayback)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject PlaylistBox::staticMetaObject = {
    { &QTreeWidget::staticMetaObject, qt_meta_stringdata_PlaylistBox.data,
      qt_meta_data_PlaylistBox,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *PlaylistBox::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlaylistBox::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_PlaylistBox.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "PlaylistCollection"))
        return static_cast< PlaylistCollection*>(this);
    return QTreeWidget::qt_metacast(_clname);
}

int PlaylistBox::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void PlaylistBox::signalPlaylistDestroyed(Playlist * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void PlaylistBox::startupComplete()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PlaylistBox::startFilePlayback(const FileHandle & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
struct qt_meta_stringdata_PlaylistBox__Item_t {
    QByteArrayData data[4];
    char stringdata0[36];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PlaylistBox__Item_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PlaylistBox__Item_t qt_meta_stringdata_PlaylistBox__Item = {
    {
QT_MOC_LITERAL(0, 0, 17), // "PlaylistBox::Item"
QT_MOC_LITERAL(1, 18, 11), // "slotSetName"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 4) // "name"

    },
    "PlaylistBox::Item\0slotSetName\0\0name"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PlaylistBox__Item[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    3,

       0        // eod
};

void PlaylistBox::Item::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Item *_t = static_cast<Item *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotSetName((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject PlaylistBox::Item::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_PlaylistBox__Item.data,
      qt_meta_data_PlaylistBox__Item,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *PlaylistBox::Item::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlaylistBox::Item::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_PlaylistBox__Item.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QTreeWidgetItem"))
        return static_cast< QTreeWidgetItem*>(this);
    if (!strcmp(_clname, "PlaylistObserver"))
        return static_cast< PlaylistObserver*>(this);
    return QObject::qt_metacast(_clname);
}

int PlaylistBox::Item::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
