/****************************************************************************
** Meta object code from reading C++ file 'directorylist.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/juk-17.12.3/directorylist.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'directorylist.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DirectoryListBase_t {
    QByteArrayData data[1];
    char stringdata0[18];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DirectoryListBase_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DirectoryListBase_t qt_meta_stringdata_DirectoryListBase = {
    {
QT_MOC_LITERAL(0, 0, 17) // "DirectoryListBase"

    },
    "DirectoryListBase"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DirectoryListBase[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void DirectoryListBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject DirectoryListBase::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_DirectoryListBase.data,
      qt_meta_data_DirectoryListBase,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *DirectoryListBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DirectoryListBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DirectoryListBase.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::DirectoryListBase"))
        return static_cast< Ui::DirectoryListBase*>(this);
    return QWidget::qt_metacast(_clname);
}

int DirectoryListBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_DirectoryList_t {
    QByteArrayData data[12];
    char stringdata0[220];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DirectoryList_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DirectoryList_t qt_meta_stringdata_DirectoryList = {
    {
QT_MOC_LITERAL(0, 0, 13), // "DirectoryList"
QT_MOC_LITERAL(1, 14, 20), // "signalDirectoryAdded"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 9), // "directory"
QT_MOC_LITERAL(4, 46, 22), // "signalDirectoryRemoved"
QT_MOC_LITERAL(5, 69, 27), // "signalExcludeDirectoryAdded"
QT_MOC_LITERAL(6, 97, 29), // "signalExcludeDirectoryRemoved"
QT_MOC_LITERAL(7, 127, 4), // "exec"
QT_MOC_LITERAL(8, 132, 16), // "slotAddDirectory"
QT_MOC_LITERAL(9, 149, 19), // "slotRemoveDirectory"
QT_MOC_LITERAL(10, 169, 23), // "slotAddExcludeDirectory"
QT_MOC_LITERAL(11, 193, 26) // "slotRemoveExcludeDirectory"

    },
    "DirectoryList\0signalDirectoryAdded\0\0"
    "directory\0signalDirectoryRemoved\0"
    "signalExcludeDirectoryAdded\0"
    "signalExcludeDirectoryRemoved\0exec\0"
    "slotAddDirectory\0slotRemoveDirectory\0"
    "slotAddExcludeDirectory\0"
    "slotRemoveExcludeDirectory"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DirectoryList[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   59,    2, 0x06 /* Public */,
       4,    1,   62,    2, 0x06 /* Public */,
       5,    1,   65,    2, 0x06 /* Public */,
       6,    1,   68,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    0,   71,    2, 0x0a /* Public */,
       8,    0,   72,    2, 0x08 /* Private */,
       9,    0,   73,    2, 0x08 /* Private */,
      10,    0,   74,    2, 0x08 /* Private */,
      11,    0,   75,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString,    3,

 // slots: parameters
    QMetaType::Int,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void DirectoryList::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        DirectoryList *_t = static_cast<DirectoryList *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->signalDirectoryAdded((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->signalDirectoryRemoved((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->signalExcludeDirectoryAdded((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->signalExcludeDirectoryRemoved((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: { int _r = _t->exec();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->slotAddDirectory(); break;
        case 6: _t->slotRemoveDirectory(); break;
        case 7: _t->slotAddExcludeDirectory(); break;
        case 8: _t->slotRemoveExcludeDirectory(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (DirectoryList::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DirectoryList::signalDirectoryAdded)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (DirectoryList::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DirectoryList::signalDirectoryRemoved)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (DirectoryList::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DirectoryList::signalExcludeDirectoryAdded)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (DirectoryList::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DirectoryList::signalExcludeDirectoryRemoved)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject DirectoryList::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_DirectoryList.data,
      qt_meta_data_DirectoryList,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *DirectoryList::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DirectoryList::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DirectoryList.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int DirectoryList::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void DirectoryList::signalDirectoryAdded(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void DirectoryList::signalDirectoryRemoved(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void DirectoryList::signalExcludeDirectoryAdded(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void DirectoryList::signalExcludeDirectoryRemoved(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
