/****************************************************************************
** Meta object code from reading C++ file 'dbuscollectionproxy.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/juk-17.12.3/dbuscollectionproxy.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbuscollectionproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DBusCollectionProxy_t {
    QByteArrayData data[21];
    char stringdata0[237];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DBusCollectionProxy_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DBusCollectionProxy_t qt_meta_stringdata_DBusCollectionProxy = {
    {
QT_MOC_LITERAL(0, 0, 19), // "DBusCollectionProxy"
QT_MOC_LITERAL(1, 20, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 36, 22), // "org.kde.juk.collection"
QT_MOC_LITERAL(3, 59, 8), // "openFile"
QT_MOC_LITERAL(4, 68, 0), // ""
QT_MOC_LITERAL(5, 69, 4), // "file"
QT_MOC_LITERAL(6, 74, 5), // "files"
QT_MOC_LITERAL(7, 80, 8), // "playlist"
QT_MOC_LITERAL(8, 89, 15), // "visiblePlaylist"
QT_MOC_LITERAL(9, 105, 15), // "playingPlaylist"
QT_MOC_LITERAL(10, 121, 9), // "playlists"
QT_MOC_LITERAL(11, 131, 14), // "playlistTracks"
QT_MOC_LITERAL(12, 146, 13), // "trackProperty"
QT_MOC_LITERAL(13, 160, 8), // "property"
QT_MOC_LITERAL(14, 169, 14), // "createPlaylist"
QT_MOC_LITERAL(15, 184, 4), // "name"
QT_MOC_LITERAL(16, 189, 11), // "setPlaylist"
QT_MOC_LITERAL(17, 201, 6), // "remove"
QT_MOC_LITERAL(18, 208, 11), // "removeTrack"
QT_MOC_LITERAL(19, 220, 10), // "trackCover"
QT_MOC_LITERAL(20, 231, 5) // "track"

    },
    "DBusCollectionProxy\0D-Bus Interface\0"
    "org.kde.juk.collection\0openFile\0\0file\0"
    "files\0playlist\0visiblePlaylist\0"
    "playingPlaylist\0playlists\0playlistTracks\0"
    "trackProperty\0property\0createPlaylist\0"
    "name\0setPlaylist\0remove\0removeTrack\0"
    "trackCover\0track"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DBusCollectionProxy[] = {

 // content:
       7,       // revision
       0,       // classname
       1,   14, // classinfo
      14,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // classinfo: key, value
       1,    2,

 // slots: name, argc, parameters, tag, flags
       3,    1,   86,    4, 0x0a /* Public */,
       3,    1,   89,    4, 0x0a /* Public */,
       3,    2,   92,    4, 0x0a /* Public */,
       3,    2,   97,    4, 0x0a /* Public */,
       8,    0,  102,    4, 0x0a /* Public */,
       9,    0,  103,    4, 0x0a /* Public */,
      10,    0,  104,    4, 0x0a /* Public */,
      11,    1,  105,    4, 0x0a /* Public */,
      12,    2,  108,    4, 0x0a /* Public */,
      14,    1,  113,    4, 0x0a /* Public */,
      16,    1,  116,    4, 0x0a /* Public */,
      17,    0,  119,    4, 0x0a /* Public */,
      18,    2,  120,    4, 0x0a /* Public */,
      19,    1,  125,    4, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    5,
    QMetaType::Void, QMetaType::QStringList,    6,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    7,    5,
    QMetaType::Void, QMetaType::QString, QMetaType::QStringList,    7,    6,
    QMetaType::QString,
    QMetaType::QString,
    QMetaType::QStringList,
    QMetaType::QStringList, QMetaType::QString,    7,
    QMetaType::QString, QMetaType::QString, QMetaType::QString,    5,   13,
    QMetaType::Void, QMetaType::QString,   15,
    QMetaType::Void, QMetaType::QString,   15,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QStringList,    7,    6,
    QMetaType::QString, QMetaType::QString,   20,

       0        // eod
};

void DBusCollectionProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        DBusCollectionProxy *_t = static_cast<DBusCollectionProxy *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->openFile((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->openFile((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 2: _t->openFile((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 3: _t->openFile((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 4: { QString _r = _t->visiblePlaylist();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { QString _r = _t->playingPlaylist();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { QStringList _r = _t->playlists();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 7: { QStringList _r = _t->playlistTracks((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 8: { QString _r = _t->trackProperty((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->createPlaylist((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 10: _t->setPlaylist((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 11: _t->remove(); break;
        case 12: _t->removeTrack((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QStringList(*)>(_a[2]))); break;
        case 13: { QString _r = _t->trackCover((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject DBusCollectionProxy::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_DBusCollectionProxy.data,
      qt_meta_data_DBusCollectionProxy,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *DBusCollectionProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBusCollectionProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DBusCollectionProxy.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DBusCollectionProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 14;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
