/****************************************************************************
** Meta object code from reading C++ file 'nowplaying.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/juk-17.12.3/nowplaying.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'nowplaying.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_NowPlaying_t {
    QByteArrayData data[7];
    char stringdata0[78];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_NowPlaying_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_NowPlaying_t qt_meta_stringdata_NowPlaying = {
    {
QT_MOC_LITERAL(0, 0, 10), // "NowPlaying"
QT_MOC_LITERAL(1, 11, 16), // "nowPlayingHidden"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 10), // "slotUpdate"
QT_MOC_LITERAL(4, 40, 10), // "FileHandle"
QT_MOC_LITERAL(5, 51, 4), // "file"
QT_MOC_LITERAL(6, 56, 21) // "slotReloadCurrentItem"

    },
    "NowPlaying\0nowPlayingHidden\0\0slotUpdate\0"
    "FileHandle\0file\0slotReloadCurrentItem"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_NowPlaying[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   29,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,   30,    2, 0x0a /* Public */,
       6,    0,   33,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void,

       0        // eod
};

void NowPlaying::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        NowPlaying *_t = static_cast<NowPlaying *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->nowPlayingHidden(); break;
        case 1: _t->slotUpdate((*reinterpret_cast< const FileHandle(*)>(_a[1]))); break;
        case 2: _t->slotReloadCurrentItem(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (NowPlaying::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&NowPlaying::nowPlayingHidden)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject NowPlaying::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_NowPlaying.data,
      qt_meta_data_NowPlaying,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *NowPlaying::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NowPlaying::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_NowPlaying.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int NowPlaying::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void NowPlaying::nowPlayingHidden()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_TrackItem_t {
    QByteArrayData data[6];
    char stringdata0[58];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_TrackItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_TrackItem_t qt_meta_stringdata_TrackItem = {
    {
QT_MOC_LITERAL(0, 0, 9), // "TrackItem"
QT_MOC_LITERAL(1, 10, 12), // "slotOpenLink"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 4), // "link"
QT_MOC_LITERAL(4, 29, 10), // "slotUpdate"
QT_MOC_LITERAL(5, 40, 17) // "slotClearShowMore"

    },
    "TrackItem\0slotOpenLink\0\0link\0slotUpdate\0"
    "slotClearShowMore"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_TrackItem[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   29,    2, 0x08 /* Private */,
       4,    0,   32,    2, 0x08 /* Private */,
       5,    0,   33,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void TrackItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TrackItem *_t = static_cast<TrackItem *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotOpenLink((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->slotUpdate(); break;
        case 2: _t->slotClearShowMore(); break;
        default: ;
        }
    }
}

const QMetaObject TrackItem::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_TrackItem.data,
      qt_meta_data_TrackItem,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *TrackItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TrackItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_TrackItem.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "NowPlayingItem"))
        return static_cast< NowPlayingItem*>(this);
    return QWidget::qt_metacast(_clname);
}

int TrackItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
