/****************************************************************************
** Meta object code from reading C++ file 'playlistcollection.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/juk-17.12.3/playlistcollection.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'playlistcollection.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_PlaylistCollection__ActionHandler_t {
    QByteArrayData data[38];
    char stringdata0[624];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PlaylistCollection__ActionHandler_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PlaylistCollection__ActionHandler_t qt_meta_stringdata_PlaylistCollection__ActionHandler = {
    {
QT_MOC_LITERAL(0, 0, 33), // "PlaylistCollection::ActionHan..."
QT_MOC_LITERAL(1, 34, 26), // "signalSelectedItemsChanged"
QT_MOC_LITERAL(2, 61, 0), // ""
QT_MOC_LITERAL(3, 62, 18), // "signalCountChanged"
QT_MOC_LITERAL(4, 81, 13), // "slotPlayFirst"
QT_MOC_LITERAL(5, 95, 17), // "slotPlayNextAlbum"
QT_MOC_LITERAL(6, 113, 8), // "slotOpen"
QT_MOC_LITERAL(7, 122, 17), // "slotManageFolders"
QT_MOC_LITERAL(8, 140, 10), // "slotRename"
QT_MOC_LITERAL(9, 151, 13), // "slotDuplicate"
QT_MOC_LITERAL(10, 165, 8), // "slotSave"
QT_MOC_LITERAL(11, 174, 10), // "slotSaveAs"
QT_MOC_LITERAL(12, 185, 10), // "slotReload"
QT_MOC_LITERAL(13, 196, 10), // "slotRemove"
QT_MOC_LITERAL(14, 207, 14), // "slotEditSearch"
QT_MOC_LITERAL(15, 222, 15), // "slotRemoveItems"
QT_MOC_LITERAL(16, 238, 16), // "slotRefreshItems"
QT_MOC_LITERAL(17, 255, 15), // "slotRenameItems"
QT_MOC_LITERAL(18, 271, 15), // "slotScanFolders"
QT_MOC_LITERAL(19, 287, 14), // "slotViewCovers"
QT_MOC_LITERAL(20, 302, 16), // "slotRemoveCovers"
QT_MOC_LITERAL(21, 319, 17), // "slotAddLocalCover"
QT_MOC_LITERAL(22, 337, 20), // "slotAddInternetCover"
QT_MOC_LITERAL(23, 358, 18), // "slotCreatePlaylist"
QT_MOC_LITERAL(24, 377, 24), // "slotCreateSearchPlaylist"
QT_MOC_LITERAL(25, 402, 24), // "slotCreateFolderPlaylist"
QT_MOC_LITERAL(26, 427, 20), // "slotGuessTagFromFile"
QT_MOC_LITERAL(27, 448, 24), // "slotGuessTagFromInternet"
QT_MOC_LITERAL(28, 473, 20), // "slotSetSearchEnabled"
QT_MOC_LITERAL(29, 494, 6), // "enable"
QT_MOC_LITERAL(30, 501, 30), // "slotSetUpcomingPlaylistEnabled"
QT_MOC_LITERAL(31, 532, 20), // "slotShowCoverManager"
QT_MOC_LITERAL(32, 553, 18), // "slotEnableDirWatch"
QT_MOC_LITERAL(33, 572, 14), // "slotDirChanged"
QT_MOC_LITERAL(34, 587, 4), // "path"
QT_MOC_LITERAL(35, 592, 12), // "slotNewItems"
QT_MOC_LITERAL(36, 605, 13), // "KFileItemList"
QT_MOC_LITERAL(37, 619, 4) // "list"

    },
    "PlaylistCollection::ActionHandler\0"
    "signalSelectedItemsChanged\0\0"
    "signalCountChanged\0slotPlayFirst\0"
    "slotPlayNextAlbum\0slotOpen\0slotManageFolders\0"
    "slotRename\0slotDuplicate\0slotSave\0"
    "slotSaveAs\0slotReload\0slotRemove\0"
    "slotEditSearch\0slotRemoveItems\0"
    "slotRefreshItems\0slotRenameItems\0"
    "slotScanFolders\0slotViewCovers\0"
    "slotRemoveCovers\0slotAddLocalCover\0"
    "slotAddInternetCover\0slotCreatePlaylist\0"
    "slotCreateSearchPlaylist\0"
    "slotCreateFolderPlaylist\0slotGuessTagFromFile\0"
    "slotGuessTagFromInternet\0slotSetSearchEnabled\0"
    "enable\0slotSetUpcomingPlaylistEnabled\0"
    "slotShowCoverManager\0slotEnableDirWatch\0"
    "slotDirChanged\0path\0slotNewItems\0"
    "KFileItemList\0list"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PlaylistCollection__ActionHandler[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      32,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  174,    2, 0x06 /* Public */,
       3,    0,  175,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,  176,    2, 0x08 /* Private */,
       5,    0,  177,    2, 0x08 /* Private */,
       6,    0,  178,    2, 0x08 /* Private */,
       7,    0,  179,    2, 0x08 /* Private */,
       8,    0,  180,    2, 0x08 /* Private */,
       9,    0,  181,    2, 0x08 /* Private */,
      10,    0,  182,    2, 0x08 /* Private */,
      11,    0,  183,    2, 0x08 /* Private */,
      12,    0,  184,    2, 0x08 /* Private */,
      13,    0,  185,    2, 0x08 /* Private */,
      14,    0,  186,    2, 0x08 /* Private */,
      15,    0,  187,    2, 0x08 /* Private */,
      16,    0,  188,    2, 0x08 /* Private */,
      17,    0,  189,    2, 0x08 /* Private */,
      18,    0,  190,    2, 0x08 /* Private */,
      19,    0,  191,    2, 0x08 /* Private */,
      20,    0,  192,    2, 0x08 /* Private */,
      21,    0,  193,    2, 0x08 /* Private */,
      22,    0,  194,    2, 0x08 /* Private */,
      23,    0,  195,    2, 0x08 /* Private */,
      24,    0,  196,    2, 0x08 /* Private */,
      25,    0,  197,    2, 0x08 /* Private */,
      26,    0,  198,    2, 0x08 /* Private */,
      27,    0,  199,    2, 0x08 /* Private */,
      28,    1,  200,    2, 0x08 /* Private */,
      30,    1,  203,    2, 0x08 /* Private */,
      31,    0,  206,    2, 0x08 /* Private */,
      32,    1,  207,    2, 0x08 /* Private */,
      33,    1,  210,    2, 0x08 /* Private */,
      35,    1,  213,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   29,
    QMetaType::Void, QMetaType::Bool,   29,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   29,
    QMetaType::Void, QMetaType::QString,   34,
    QMetaType::Void, 0x80000000 | 36,   37,

       0        // eod
};

void PlaylistCollection::ActionHandler::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ActionHandler *_t = static_cast<ActionHandler *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->signalSelectedItemsChanged(); break;
        case 1: _t->signalCountChanged(); break;
        case 2: _t->slotPlayFirst(); break;
        case 3: _t->slotPlayNextAlbum(); break;
        case 4: _t->slotOpen(); break;
        case 5: _t->slotManageFolders(); break;
        case 6: _t->slotRename(); break;
        case 7: _t->slotDuplicate(); break;
        case 8: _t->slotSave(); break;
        case 9: _t->slotSaveAs(); break;
        case 10: _t->slotReload(); break;
        case 11: _t->slotRemove(); break;
        case 12: _t->slotEditSearch(); break;
        case 13: _t->slotRemoveItems(); break;
        case 14: _t->slotRefreshItems(); break;
        case 15: _t->slotRenameItems(); break;
        case 16: _t->slotScanFolders(); break;
        case 17: _t->slotViewCovers(); break;
        case 18: _t->slotRemoveCovers(); break;
        case 19: _t->slotAddLocalCover(); break;
        case 20: _t->slotAddInternetCover(); break;
        case 21: _t->slotCreatePlaylist(); break;
        case 22: _t->slotCreateSearchPlaylist(); break;
        case 23: _t->slotCreateFolderPlaylist(); break;
        case 24: _t->slotGuessTagFromFile(); break;
        case 25: _t->slotGuessTagFromInternet(); break;
        case 26: _t->slotSetSearchEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 27: _t->slotSetUpcomingPlaylistEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 28: _t->slotShowCoverManager(); break;
        case 29: _t->slotEnableDirWatch((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 30: _t->slotDirChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 31: _t->slotNewItems((*reinterpret_cast< const KFileItemList(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ActionHandler::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ActionHandler::signalSelectedItemsChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (ActionHandler::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ActionHandler::signalCountChanged)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject PlaylistCollection::ActionHandler::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_PlaylistCollection__ActionHandler.data,
      qt_meta_data_PlaylistCollection__ActionHandler,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *PlaylistCollection::ActionHandler::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlaylistCollection::ActionHandler::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_PlaylistCollection__ActionHandler.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PlaylistCollection::ActionHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 32;
    }
    return _id;
}

// SIGNAL 0
void PlaylistCollection::ActionHandler::signalSelectedItemsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PlaylistCollection::ActionHandler::signalCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
