/****************************************************************************
** Meta object code from reading C++ file 'playermanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/juk-17.12.3/playermanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'playermanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_PlayerManager_t {
    QByteArrayData data[43];
    char stringdata0[443];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PlayerManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PlayerManager_t qt_meta_stringdata_PlayerManager = {
    {
QT_MOC_LITERAL(0, 0, 13), // "PlayerManager"
QT_MOC_LITERAL(1, 14, 4), // "tick"
QT_MOC_LITERAL(2, 19, 0), // ""
QT_MOC_LITERAL(3, 20, 16), // "totalTimeChanged"
QT_MOC_LITERAL(4, 37, 12), // "mutedChanged"
QT_MOC_LITERAL(5, 50, 5), // "muted"
QT_MOC_LITERAL(6, 56, 13), // "volumeChanged"
QT_MOC_LITERAL(7, 70, 6), // "volume"
QT_MOC_LITERAL(8, 77, 6), // "seeked"
QT_MOC_LITERAL(9, 84, 6), // "newPos"
QT_MOC_LITERAL(10, 91, 15), // "seekableChanged"
QT_MOC_LITERAL(11, 107, 10), // "signalPlay"
QT_MOC_LITERAL(12, 118, 11), // "signalPause"
QT_MOC_LITERAL(13, 130, 10), // "signalStop"
QT_MOC_LITERAL(14, 141, 17), // "signalItemChanged"
QT_MOC_LITERAL(15, 159, 10), // "FileHandle"
QT_MOC_LITERAL(16, 170, 4), // "file"
QT_MOC_LITERAL(17, 175, 4), // "play"
QT_MOC_LITERAL(18, 180, 5), // "pause"
QT_MOC_LITERAL(19, 186, 4), // "stop"
QT_MOC_LITERAL(20, 191, 9), // "setVolume"
QT_MOC_LITERAL(21, 201, 4), // "seek"
QT_MOC_LITERAL(22, 206, 8), // "seekTime"
QT_MOC_LITERAL(23, 215, 11), // "seekForward"
QT_MOC_LITERAL(24, 227, 8), // "seekBack"
QT_MOC_LITERAL(25, 236, 9), // "playPause"
QT_MOC_LITERAL(26, 246, 7), // "forward"
QT_MOC_LITERAL(27, 254, 4), // "back"
QT_MOC_LITERAL(28, 259, 8), // "volumeUp"
QT_MOC_LITERAL(29, 268, 10), // "volumeDown"
QT_MOC_LITERAL(30, 279, 8), // "setMuted"
QT_MOC_LITERAL(31, 288, 1), // "m"
QT_MOC_LITERAL(32, 290, 4), // "mute"
QT_MOC_LITERAL(33, 295, 17), // "setRandomPlayMode"
QT_MOC_LITERAL(34, 313, 10), // "randomMode"
QT_MOC_LITERAL(35, 324, 12), // "slotFinished"
QT_MOC_LITERAL(36, 337, 10), // "slotLength"
QT_MOC_LITERAL(37, 348, 8), // "slotTick"
QT_MOC_LITERAL(38, 357, 16), // "slotStateChanged"
QT_MOC_LITERAL(39, 374, 13), // "Phonon::State"
QT_MOC_LITERAL(40, 388, 19), // "slotSeekableChanged"
QT_MOC_LITERAL(41, 408, 16), // "slotMutedChanged"
QT_MOC_LITERAL(42, 425, 17) // "slotVolumeChanged"

    },
    "PlayerManager\0tick\0\0totalTimeChanged\0"
    "mutedChanged\0muted\0volumeChanged\0"
    "volume\0seeked\0newPos\0seekableChanged\0"
    "signalPlay\0signalPause\0signalStop\0"
    "signalItemChanged\0FileHandle\0file\0"
    "play\0pause\0stop\0setVolume\0seek\0seekTime\0"
    "seekForward\0seekBack\0playPause\0forward\0"
    "back\0volumeUp\0volumeDown\0setMuted\0m\0"
    "mute\0setRandomPlayMode\0randomMode\0"
    "slotFinished\0slotLength\0slotTick\0"
    "slotStateChanged\0Phonon::State\0"
    "slotSeekableChanged\0slotMutedChanged\0"
    "slotVolumeChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PlayerManager[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      35,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      10,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  189,    2, 0x06 /* Public */,
       3,    1,  192,    2, 0x06 /* Public */,
       4,    1,  195,    2, 0x06 /* Public */,
       6,    1,  198,    2, 0x06 /* Public */,
       8,    1,  201,    2, 0x06 /* Public */,
      10,    1,  204,    2, 0x06 /* Public */,
      11,    0,  207,    2, 0x06 /* Public */,
      12,    0,  208,    2, 0x06 /* Public */,
      13,    0,  209,    2, 0x06 /* Public */,
      14,    1,  210,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      17,    1,  213,    2, 0x0a /* Public */,
      17,    1,  216,    2, 0x0a /* Public */,
      17,    0,  219,    2, 0x0a /* Public */,
      18,    0,  220,    2, 0x0a /* Public */,
      19,    0,  221,    2, 0x0a /* Public */,
      20,    1,  222,    2, 0x0a /* Public */,
      20,    0,  225,    2, 0x2a /* Public | MethodCloned */,
      21,    1,  226,    2, 0x0a /* Public */,
      23,    0,  229,    2, 0x0a /* Public */,
      24,    0,  230,    2, 0x0a /* Public */,
      25,    0,  231,    2, 0x0a /* Public */,
      26,    0,  232,    2, 0x0a /* Public */,
      27,    0,  233,    2, 0x0a /* Public */,
      28,    0,  234,    2, 0x0a /* Public */,
      29,    0,  235,    2, 0x0a /* Public */,
      30,    1,  236,    2, 0x0a /* Public */,
      32,    0,  239,    2, 0x0a /* Public */,
      33,    1,  240,    2, 0x0a /* Public */,
      35,    0,  243,    2, 0x08 /* Private */,
      36,    1,  244,    2, 0x08 /* Private */,
      37,    1,  247,    2, 0x08 /* Private */,
      38,    2,  250,    2, 0x08 /* Private */,
      40,    1,  255,    2, 0x08 /* Private */,
      41,    1,  258,    2, 0x08 /* Private */,
      42,    1,  261,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::LongLong,    2,
    QMetaType::Void, QMetaType::LongLong,    2,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void, QMetaType::Float,    7,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 15,   16,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 15,   16,
    QMetaType::Void, QMetaType::QString,   16,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Float,    7,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   22,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   31,
    QMetaType::Bool,
    QMetaType::Void, QMetaType::QString,   34,
    QMetaType::Void,
    QMetaType::Void, QMetaType::LongLong,    2,
    QMetaType::Void, QMetaType::LongLong,    2,
    QMetaType::Void, 0x80000000 | 39, 0x80000000 | 39,    2,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::QReal,    2,

       0        // eod
};

void PlayerManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        PlayerManager *_t = static_cast<PlayerManager *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->tick((*reinterpret_cast< qint64(*)>(_a[1]))); break;
        case 1: _t->totalTimeChanged((*reinterpret_cast< qint64(*)>(_a[1]))); break;
        case 2: _t->mutedChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->volumeChanged((*reinterpret_cast< float(*)>(_a[1]))); break;
        case 4: _t->seeked((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->seekableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->signalPlay(); break;
        case 7: _t->signalPause(); break;
        case 8: _t->signalStop(); break;
        case 9: _t->signalItemChanged((*reinterpret_cast< const FileHandle(*)>(_a[1]))); break;
        case 10: _t->play((*reinterpret_cast< const FileHandle(*)>(_a[1]))); break;
        case 11: _t->play((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 12: _t->play(); break;
        case 13: _t->pause(); break;
        case 14: _t->stop(); break;
        case 15: _t->setVolume((*reinterpret_cast< float(*)>(_a[1]))); break;
        case 16: _t->setVolume(); break;
        case 17: _t->seek((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->seekForward(); break;
        case 19: _t->seekBack(); break;
        case 20: _t->playPause(); break;
        case 21: _t->forward(); break;
        case 22: _t->back(); break;
        case 23: _t->volumeUp(); break;
        case 24: _t->volumeDown(); break;
        case 25: _t->setMuted((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 26: { bool _r = _t->mute();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->setRandomPlayMode((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 28: _t->slotFinished(); break;
        case 29: _t->slotLength((*reinterpret_cast< qint64(*)>(_a[1]))); break;
        case 30: _t->slotTick((*reinterpret_cast< qint64(*)>(_a[1]))); break;
        case 31: _t->slotStateChanged((*reinterpret_cast< Phonon::State(*)>(_a[1])),(*reinterpret_cast< Phonon::State(*)>(_a[2]))); break;
        case 32: _t->slotSeekableChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 33: _t->slotMutedChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 34: _t->slotVolumeChanged((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Phonon::State >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (PlayerManager::*_t)(qint64 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerManager::tick)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (PlayerManager::*_t)(qint64 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerManager::totalTimeChanged)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (PlayerManager::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerManager::mutedChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (PlayerManager::*_t)(float );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerManager::volumeChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (PlayerManager::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerManager::seeked)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (PlayerManager::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerManager::seekableChanged)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (PlayerManager::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerManager::signalPlay)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (PlayerManager::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerManager::signalPause)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (PlayerManager::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerManager::signalStop)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (PlayerManager::*_t)(const FileHandle & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerManager::signalItemChanged)) {
                *result = 9;
                return;
            }
        }
    }
}

const QMetaObject PlayerManager::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_PlayerManager.data,
      qt_meta_data_PlayerManager,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *PlayerManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlayerManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_PlayerManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PlayerManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    return _id;
}

// SIGNAL 0
void PlayerManager::tick(qint64 _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void PlayerManager::totalTimeChanged(qint64 _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void PlayerManager::mutedChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void PlayerManager::volumeChanged(float _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void PlayerManager::seeked(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void PlayerManager::seekableChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void PlayerManager::signalPlay()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void PlayerManager::signalPause()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void PlayerManager::signalStop()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void PlayerManager::signalItemChanged(const FileHandle & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
