/****************************************************************************
** Meta object code from reading C++ file 'tageditor.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/juk-17.12.3/tageditor.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tageditor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_TagEditor_t {
    QByteArrayData data[17];
    char stringdata0[203];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_TagEditor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_TagEditor_t qt_meta_stringdata_TagEditor = {
    {
QT_MOC_LITERAL(0, 0, 9), // "TagEditor"
QT_MOC_LITERAL(1, 10, 8), // "slotSave"
QT_MOC_LITERAL(2, 19, 0), // ""
QT_MOC_LITERAL(3, 20, 12), // "slotSetItems"
QT_MOC_LITERAL(4, 33, 16), // "PlaylistItemList"
QT_MOC_LITERAL(5, 50, 4), // "list"
QT_MOC_LITERAL(6, 55, 11), // "slotRefresh"
QT_MOC_LITERAL(7, 67, 9), // "slotClear"
QT_MOC_LITERAL(8, 77, 21), // "slotPlaylistDestroyed"
QT_MOC_LITERAL(9, 99, 9), // "Playlist*"
QT_MOC_LITERAL(10, 109, 1), // "p"
QT_MOC_LITERAL(11, 111, 20), // "slotUpdateCollection"
QT_MOC_LITERAL(12, 132, 15), // "slotDataChanged"
QT_MOC_LITERAL(13, 148, 15), // "slotItemRemoved"
QT_MOC_LITERAL(14, 164, 13), // "PlaylistItem*"
QT_MOC_LITERAL(15, 178, 4), // "item"
QT_MOC_LITERAL(16, 183, 19) // "slotPlaylistRemoved"

    },
    "TagEditor\0slotSave\0\0slotSetItems\0"
    "PlaylistItemList\0list\0slotRefresh\0"
    "slotClear\0slotPlaylistDestroyed\0"
    "Playlist*\0p\0slotUpdateCollection\0"
    "slotDataChanged\0slotItemRemoved\0"
    "PlaylistItem*\0item\0slotPlaylistRemoved"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_TagEditor[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x0a /* Public */,
       3,    1,   60,    2, 0x0a /* Public */,
       6,    0,   63,    2, 0x0a /* Public */,
       7,    0,   64,    2, 0x0a /* Public */,
       8,    1,   65,    2, 0x0a /* Public */,
      11,    0,   68,    2, 0x0a /* Public */,
      12,    0,   69,    2, 0x08 /* Private */,
      13,    1,   70,    2, 0x08 /* Private */,
      16,    0,   73,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 14,   15,
    QMetaType::Void,

       0        // eod
};

void TagEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TagEditor *_t = static_cast<TagEditor *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->slotSave(); break;
        case 1: _t->slotSetItems((*reinterpret_cast< const PlaylistItemList(*)>(_a[1]))); break;
        case 2: _t->slotRefresh(); break;
        case 3: _t->slotClear(); break;
        case 4: _t->slotPlaylistDestroyed((*reinterpret_cast< Playlist*(*)>(_a[1]))); break;
        case 5: _t->slotUpdateCollection(); break;
        case 6: _t->slotDataChanged(); break;
        case 7: _t->slotItemRemoved((*reinterpret_cast< PlaylistItem*(*)>(_a[1]))); break;
        case 8: _t->slotPlaylistRemoved(); break;
        default: ;
        }
    }
}

const QMetaObject TagEditor::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_TagEditor.data,
      qt_meta_data_TagEditor,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *TagEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TagEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_TagEditor.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::TagEditor"))
        return static_cast< Ui::TagEditor*>(this);
    return QWidget::qt_metacast(_clname);
}

int TagEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
