/****************************************************************************
** Meta object code from reading C++ file 'playlistsplitter.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/juk-17.12.3/playlistsplitter.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'playlistsplitter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_PlaylistSplitter_t {
    QByteArrayData data[16];
    char stringdata0[251];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PlaylistSplitter_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PlaylistSplitter_t qt_meta_stringdata_PlaylistSplitter = {
    {
QT_MOC_LITERAL(0, 0, 16), // "PlaylistSplitter"
QT_MOC_LITERAL(1, 17, 8), // "guiReady"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 22), // "currentPlaylistChanged"
QT_MOC_LITERAL(4, 50, 17), // "PlaylistInterface"
QT_MOC_LITERAL(5, 68, 15), // "currentPlaylist"
QT_MOC_LITERAL(6, 84, 8), // "setFocus"
QT_MOC_LITERAL(7, 93, 24), // "slotFocusCurrentPlaylist"
QT_MOC_LITERAL(8, 118, 10), // "slotEnable"
QT_MOC_LITERAL(9, 129, 21), // "slotShowSearchResults"
QT_MOC_LITERAL(10, 151, 28), // "slotPlaylistSelectionChanged"
QT_MOC_LITERAL(11, 180, 19), // "slotPlaylistChanged"
QT_MOC_LITERAL(12, 200, 1), // "i"
QT_MOC_LITERAL(13, 202, 26), // "slotCurrentPlaylistChanged"
QT_MOC_LITERAL(14, 229, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(15, 246, 4) // "item"

    },
    "PlaylistSplitter\0guiReady\0\0"
    "currentPlaylistChanged\0PlaylistInterface\0"
    "currentPlaylist\0setFocus\0"
    "slotFocusCurrentPlaylist\0slotEnable\0"
    "slotShowSearchResults\0"
    "slotPlaylistSelectionChanged\0"
    "slotPlaylistChanged\0i\0slotCurrentPlaylistChanged\0"
    "QTreeWidgetItem*\0item"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PlaylistSplitter[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x06 /* Public */,
       3,    1,   60,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    0,   63,    2, 0x0a /* Public */,
       7,    0,   64,    2, 0x0a /* Public */,
       8,    0,   65,    2, 0x0a /* Public */,
       9,    0,   66,    2, 0x08 /* Private */,
      10,    0,   67,    2, 0x08 /* Private */,
      11,    1,   68,    2, 0x08 /* Private */,
      13,    1,   71,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    5,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void, 0x80000000 | 14,   15,

       0        // eod
};

void PlaylistSplitter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        PlaylistSplitter *_t = static_cast<PlaylistSplitter *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->guiReady(); break;
        case 1: _t->currentPlaylistChanged((*reinterpret_cast< const PlaylistInterface(*)>(_a[1]))); break;
        case 2: _t->setFocus(); break;
        case 3: _t->slotFocusCurrentPlaylist(); break;
        case 4: _t->slotEnable(); break;
        case 5: _t->slotShowSearchResults(); break;
        case 6: _t->slotPlaylistSelectionChanged(); break;
        case 7: _t->slotPlaylistChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->slotCurrentPlaylistChanged((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (PlaylistSplitter::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlaylistSplitter::guiReady)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (PlaylistSplitter::*_t)(const PlaylistInterface & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlaylistSplitter::currentPlaylistChanged)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject PlaylistSplitter::staticMetaObject = {
    { &QSplitter::staticMetaObject, qt_meta_stringdata_PlaylistSplitter.data,
      qt_meta_data_PlaylistSplitter,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *PlaylistSplitter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlaylistSplitter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_PlaylistSplitter.stringdata0))
        return static_cast<void*>(this);
    return QSplitter::qt_metacast(_clname);
}

int PlaylistSplitter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSplitter::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void PlaylistSplitter::guiReady()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PlaylistSplitter::currentPlaylistChanged(const PlaylistInterface & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
