/****************************************************************************
** Meta object code from reading C++ file 'tagguesserconfigdlg.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../src/juk-17.12.3/tagguesserconfigdlg.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tagguesserconfigdlg.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_TagGuesserConfigDlgWidget_t {
    QByteArrayData data[1];
    char stringdata0[26];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_TagGuesserConfigDlgWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_TagGuesserConfigDlgWidget_t qt_meta_stringdata_TagGuesserConfigDlgWidget = {
    {
QT_MOC_LITERAL(0, 0, 25) // "TagGuesserConfigDlgWidget"

    },
    "TagGuesserConfigDlgWidget"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_TagGuesserConfigDlgWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void TagGuesserConfigDlgWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject TagGuesserConfigDlgWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_TagGuesserConfigDlgWidget.data,
      qt_meta_data_TagGuesserConfigDlgWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *TagGuesserConfigDlgWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TagGuesserConfigDlgWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_TagGuesserConfigDlgWidget.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::TagGuesserConfigDlgWidget"))
        return static_cast< Ui::TagGuesserConfigDlgWidget*>(this);
    return QWidget::qt_metacast(_clname);
}

int TagGuesserConfigDlgWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_TagGuesserConfigDlg_t {
    QByteArrayData data[10];
    char stringdata0[141];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_TagGuesserConfigDlg_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_TagGuesserConfigDlg_t qt_meta_stringdata_TagGuesserConfigDlg = {
    {
QT_MOC_LITERAL(0, 0, 19), // "TagGuesserConfigDlg"
QT_MOC_LITERAL(1, 20, 6), // "accept"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 18), // "slotCurrentChanged"
QT_MOC_LITERAL(4, 47, 4), // "item"
QT_MOC_LITERAL(5, 52, 17), // "slotMoveUpClicked"
QT_MOC_LITERAL(6, 70, 19), // "slotMoveDownClicked"
QT_MOC_LITERAL(7, 90, 14), // "slotAddClicked"
QT_MOC_LITERAL(8, 105, 17), // "slotModifyClicked"
QT_MOC_LITERAL(9, 123, 17) // "slotRemoveClicked"

    },
    "TagGuesserConfigDlg\0accept\0\0"
    "slotCurrentChanged\0item\0slotMoveUpClicked\0"
    "slotMoveDownClicked\0slotAddClicked\0"
    "slotModifyClicked\0slotRemoveClicked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_TagGuesserConfigDlg[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x09 /* Protected */,
       3,    1,   50,    2, 0x08 /* Private */,
       5,    0,   53,    2, 0x08 /* Private */,
       6,    0,   54,    2, 0x08 /* Private */,
       7,    0,   55,    2, 0x08 /* Private */,
       8,    0,   56,    2, 0x08 /* Private */,
       9,    0,   57,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QModelIndex,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void TagGuesserConfigDlg::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TagGuesserConfigDlg *_t = static_cast<TagGuesserConfigDlg *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->accept(); break;
        case 1: _t->slotCurrentChanged((*reinterpret_cast< QModelIndex(*)>(_a[1]))); break;
        case 2: _t->slotMoveUpClicked(); break;
        case 3: _t->slotMoveDownClicked(); break;
        case 4: _t->slotAddClicked(); break;
        case 5: _t->slotModifyClicked(); break;
        case 6: _t->slotRemoveClicked(); break;
        default: ;
        }
    }
}

const QMetaObject TagGuesserConfigDlg::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_TagGuesserConfigDlg.data,
      qt_meta_data_TagGuesserConfigDlg,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *TagGuesserConfigDlg::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TagGuesserConfigDlg::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_TagGuesserConfigDlg.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int TagGuesserConfigDlg::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
